"""Top-level package for Python Ember Mug."""
from .mug import EmberMug

__all__ = ("EmberMug",)

__author__ = """Jesse Sopel"""
__email__ = "jesse.sopel@gmail.com"
__version__ = "0.9.0"
